import game
import globals
import interface
import status
import game
import string
import pygame

def render(hud_surface):
	"Render the hud."
	draw_health_status(hud_surface)
	draw_messages(hud_surface)
	
	list = map(lambda i : i.name, game.player.items)
	draw_listbox(hud_surface, (10, 40), list, "Inventory:")

	if interface.state == interface.death:
		draw_dialog(hud_surface, "You are eaten by a grue.")


def draw_listbox(hud_surface, (x, y), list, title = None, font_size = 18, 
	              colour = (255, 255, 255, 50), margin = 5):
	"Draw a box with a list in it."
	font   = pygame.font.Font(None, font_size)
	lines  = []
	width = height = 0

	if title is not None:
		font.set_bold(True)
		text = font.render(title, 1, colour)
		lines.append(text)
		width  = text.get_width()
		height = text.get_height()
		font.set_bold(False)
	
	for item in list:
		text = font.render(item, 1, colour)
		lines.append(text)
		width   = max((width, text.get_width()))
		height += text.get_height()
	
	size = width + margin * 2, height + margin * 2 - 3
	draw_box(hud_surface, (x, y), size)
	x += margin
	y += margin

	for line in lines:
		hud_surface.blit(line, (x, y))
		y += line.get_height()		


def draw_dialog(hud_surface, string, font_size = 18, 
	              colour = (255, 255, 255, 50), margin = 5):
	"Draw a dialog box in the centre of the screen."
	font = pygame.font.Font(None, font_size)
	text = font.render(string, 1, colour)
	size = text.get_width() + margin * 2, text.get_height() + margin * 2 - 4
	
	x, y = hud_surface.get_width() / 2, hud_surface.get_height() / 2
	x, y = x - (size[0] / 2), y - (size[1] / 2)

	draw_box(hud_surface, (x, y), size)
	hud_surface.blit(text, (x + margin, y + margin))



def draw_textbox(hud_surface, (x, y), string, font_size = 18, 
	              colour = (255, 255, 255, 50), margin = 5):
	"Draw a box with text in it."
	font = pygame.font.Font(None, font_size)
	text = font.render(string, 1, colour)
	size = text.get_width() + margin * 2, text.get_height() + margin * 2
	
	draw_box(hud_surface, (x, y), size)
	hud_surface.blit(text, (x + margin, y + margin))


def draw_box(hud_surface, position, size, width = 1):
	"Draw an alpha-blended dialog box on the screen./"
	size = size[0] + width * 2, size[1] + width * 2
	box  = pygame.Surface(size)
	
	box.set_alpha(180)	
	hud_surface.blit(box, position)

	pygame.draw.rect(hud_surface, (255, 255, 255),
	pygame.Rect([position[0], position[1], size[0], size[1]]), width)


def draw_health_status(hud_surface):
	"Draw the player's current health."
	font     = pygame.font.Font(None, 18)
	string   = "HP: %d / %d" % (game.player.hp, game.player.maxhp)
	text     = font.render(string, 1, (255, 255, 255, 50))
	position = globals.screen_size[0] - text.get_width() - 10, 10
	hud_surface.blit(text, position)


def draw_messages(hud_surface):
	"Draw status messages, similar to tty nethack."

	font = pygame.font.Font(None, 18)
	string = status.get_current_message()
	
	if status.messages_waiting():
		string += " (More)"
			
	text = font.render(string, 1, (255, 255, 255, 190))
	hud_surface.blit(text, (10, 10))
