import globals
import game
import status
import tile
import light

class Item:
	"An item! Items can be contained in a tile or by a mob."
	def __init__(self, container, name, image_src):
		self.name      = name
		self.image_src = image_src
		self.container = container
		self.container.items.append(self)

	def update(self):
		pass

	def image(self):
		return self.image_src

	def die(self):
		"Die. Become unreferenced, and flag up being dead."
		self.dead = True
		self.lit  = False
		self.container.items.remove(self)
		self.container = None


class LightSource(Item):
	"A generic lightsource."
	def __init__(self, container, name, image_src, amplitude, duration):
		Item.__init__(self, container, name, image_src)
		self.amplitude = amplitude
		self.duration  = duration
		self.time      = 0
		self.lit       = True
		self.dead      = False

	def light(self):
		if self.lit:
			return self.amplitude
		else:
			return 0.0

	def update(self):
		"Light sources run out of fuel eventually..."
		if not self.lit:
			return
		self.update_illumination()

		# If on a tile and is lit, create a pool of light
		if isinstance(self.container, tile.Tile):
			light.create_radial(self.container.position, self.amplitude)


	def update_illumination(self):
		self.time += globals.turn - globals.last_turn
			
		if self.time > self.duration[0]:
			t = float(self.time - self.duration[0])
			self.amplitude *= 1.0 - (t / self.duration[1])
				
		if self.time >= (self.duration[0] + self.duration[1]):
			self.die()

		
	def die(self):
		if self.container == game.player:
			status.add_message("Your %s flickers out." % self.name)
		Item.die(self)


class Torch(LightSource):
	"A torch."
	def __init__(self, container):
		LightSource.__init__(self, container, "torch", "torch.png", 1.0, (30, 5))
