def DDA(start, end):
	"""
	Return a list of points representing a line between start and end.
	Uses the Digital Differential Analyser (DDA) method.
	Useful for raytracing the light rays in the game.
	"""
	dx = end[0] - start[0]
	dy = end[1] - start[1]

	line = [start]
	
	if dx == 0 and dy == 0:
		return line

	if abs(dx) > abs(dy):
		m = float(dy) / float(dx)
		x = start[0]
		y = start[1] + 0.5
		
		if dx < 0: dx = -1
		else:      dx = 1
		m *= dx

		while x != end[0]:
			x += dx
			y += m
			line.append((x, int(y)))
	else:
		m = float(dx) / float(dy)
		x = start[0] + 0.5
		y = start[1]

		if dy < 0: dy = -1
		else:      dy = 1
		m *= dy

		while y != end[1]:
			y += dy
			x += m
			line.append((int(x), y))

	return line
