import mob
import vector
import game
import misc

class Monster(mob.Creature):
	"This represents a generic monster."
	def __init__(self, position):
		mob.Creature.__init__(self, position, "monster.png", 
			name = "the monster", str = 20, con = 20, level = 1,
			hit_dice = (1, 6), movement_cost = 2
		)
		self.power = 1.0

	def update(self):
		"Update the monster."
		if self.dead:
			return
		self.power  = 1.0 - (self.tile.light * 0.85)
		self.simple_ai()

	def simple_ai(self):
		"Simple AI routine to walk toward the player."

		# Get direction to target
		target    = game.player.tile.position
		position  = self.tile.position
		direction = target[0] - position[0], target[1] - position[1]
		direction = vector.normalise(direction)
		dx, dy = int(round(direction[0])), int(round(direction[1]))

		# Move toward target
		self.walk((dx, dy))

	def damage(self):
		"Return the amount of damage you do in an attack."
		full_damage = misc.dice(1, 6) + misc.modifier(self.str)
		return int(self.power * full_damage + 0.5)

	def wound(self, enemy, loss):
		"Something is damaging you."
		self.hp -= int(loss / self.power) / 2
		if self.hp <= 0:
			self.die()
			enemy.killed(self)
