import misc
import globals
import game
import mapmaker
import string

class Tile:
	"A generic tile."
	def __init__(self, position, image_src = None, obstacle = False):
		self.position  = position
		self.image_src = image_src
		self.obstacle  = obstacle
		self.light     = 0.0
		self.mob       = None
		self.items     = misc.LimitedList(globals.inventory_limit)
		
		self.illuminated = False

	def image(self):
		return self.image_src


	def add_item(self, item):
		"Put an item on the tile."
		try:
			self.items.append(item)
		except error.ContainerFull:
			return
		item.container = self


class Blank(Tile):
	"A blank tile."
	def __init__(self, position):
		Tile.__init__(self, position)

class Floor(Tile):
	"A floor tile."
	def __init__(self, position):
		Tile.__init__(self, position, "floor.png")

class Wall(Tile):
	"A wall tile."
	def __init__(self, position):
		Tile.__init__(self, position, "wall-%s.png", obstacle = True)

	def get_nearby_tiles(self):
		"Get tiles that share an edge with this tile."
		x, y  = self.position
		tiles = []
		tiles.append(self._get_tile((x, y - 1)))
		tiles.append(self._get_tile((x + 1, y)))
		tiles.append(self._get_tile((x, y + 1)))
		tiles.append(self._get_tile((x - 1, y)))
		return tiles

	def _get_tile(self, position):
		"Get a tile from the game map."
		try:
			tile = mapmaker.get_tile(game.map, position)
		except IndexError:
			return None
		return tile

	def image(self):
		tiles = self.get_nearby_tiles()
		tiles = map(lambda t : (t != None) and (t.__class__ == Wall), tiles)
		tiles = map(lambda x : x and '1' or '0', tiles)
		return self.image_src % string.join(tiles, "")
