import globals
import image
import game
import pygame

# A solid black shadow square
# We'll use alpha-blending to get gradients
shadow_square = pygame.Surface(globals.tile_size)
shadow_square.fill((0, 0, 0))

def render(surface):
	"Generic rendering function for tiles."
	x, y    = (0, 0)
	
	for row in game.map:
		for tile in row:
			draw_tile(surface, tile, (x, y))
			x += globals.tile_size[0]
		y += globals.tile_size[1]
		x = 0

	return surface

def draw_tile(surface, tile, position):
	"Draw a single tile"
	draw_backdrop(surface, tile, position)
	draw_items(surface, tile, position)
	draw_mobs(surface, tile, position)
	draw_shadows(surface, tile, position)

def draw_backdrop(surface, tile, position):
	if tile.image is not None:
		surface.blit(image.load(tile.image()), position)

def draw_items(surface, tile, position):
	if tile.items != []:
		item = tile.items[0]
		surface.blit(image.load(item.image()), position)

def draw_mobs(surface, tile, position):
	if tile.mob is not None:
		surface.blit(image.load(tile.mob.image()), position)

def draw_shadows(surface, tile, position):
	"Draw a shadow-mask to go over the top of a tile."	
	alpha = 220 - int(tile.light * 220)
	shadow_square.set_alpha(alpha)
	surface.blit(shadow_square, position)
