import mob
import game
import globals
import light
import status
import misc
import error
import sys

class Player(mob.Creature):
	"This represents the player."
	def __init__(self, position, weapon = None):
		mob.Creature.__init__(self, position, "player.png", 
			name = "you", str = 16, con = 16, level = 1,
			hit_dice = (1, 10),
			weapon = weapon
		)

	def walk(self, (dx, dy)):
		"""
		Walk somewhere.
		Because the players movement determines the pace of the game, the player
		doesn't have to wait.
		"""
		position = self.tile.position
		try:
			self.move((position[0] + dx, position[1] + dy))
		except error.InvalidMobMove:
			return
			
		self.check_for_items()
		globals.turn += self.movement_cost

	def check_for_items(self):
		"Tell the player about items on the ground."
		if len(self.tile.items) > 0:
			item = self.tile.items[0].name
			status.add_message("You see %s %s" % (misc.ana(item), item))


	def attack(self, target):
		"Attack something!"
		status.add_message("You attack %s!" %  target.name)
		try:
			target.wound(self, self.damage())
		except AttributeError:
			return

	def take_item(self, item):
		"Take an item."
		self.add_item(item)
		globals.turn += self.movement_cost
	
	def update(self):
		"Update the player."
		amplitude = self.get_light_emitted()
		if amplitude > 0:
			light.create_radial(self.tile.position, amplitude)


	def get_light_emitted(self):
		"Get the total amount of light the player emits."
		total_light = 0.0
		for item in self.items:
			if hasattr(item, 'light'):
				total_light = max(total_light, item.light())
		return total_light


	def killed(self, target):
		"Killed another creature!"
		message = "You kill %s!" % target.name
		status.add_message(message)


	def die(self):
		"Game over man, game over!"
		game.gameover()
